pub trait Div<Rhs = Self> {
type Output;
// Required method
fn div(self, rhs: Rhs) -> Self::Output;
}Required Associated Types
Required Methods
Implementations on Foreign Types
Sourceimpl Div for i8
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for i8
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0 or the division results in overflow.
Sourceimpl Div for i16
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for i16
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0 or the division results in overflow.
Sourceimpl Div for i32
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for i32
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0 or the division results in overflow.
Sourceimpl Div for i64
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for i64
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0 or the division results in overflow.
Sourceimpl Div for i128
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for i128
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0 or the division results in overflow.
Sourceimpl Div for isize
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for isize
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0 or the division results in overflow.
Sourceimpl Div for u8
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for u8
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0.
Sourceimpl Div for u16
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for u16
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0.
Sourceimpl Div for u32
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for u32
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0.
Sourceimpl Div for u64
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for u64
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0.
Sourceimpl Div for u128
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for u128
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0.
Sourceimpl Div for usize
This operation rounds towards zero, truncating any
fractional part of the exact result.
impl Div for usize
This operation rounds towards zero, truncating any fractional part of the exact result.
Panics
This operation will panic if other == 0.