Rem

Trait Rem 

pub trait Rem<Rhs = Self> {
    type Output;

    // Required method
    fn rem(self, rhs: Rhs) -> Self::Output;
}

Required Associated Types

Required Methods

fn rem(self, rhs: Rhs) -> Self::Output

Implementations on Foreign Types

Source

impl Rem for i8

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

Source

type Output = i8

Source

fn rem(self, other: i8) -> i8

Source

impl Rem for i16

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

Source

type Output = i16

Source

fn rem(self, other: i16) -> i16

Source

impl Rem for i32

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

Source

type Output = i32

Source

fn rem(self, other: i32) -> i32

Source

impl Rem for i64

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

Source

type Output = i64

Source

fn rem(self, other: i64) -> i64

Source

impl Rem for i128

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

Source

type Output = i128

Source

fn rem(self, other: i128) -> i128

Source

impl Rem for isize

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

Source

type Output = isize

Source

fn rem(self, other: isize) -> isize

Source

impl Rem for u8

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

Source

type Output = u8

Source

fn rem(self, other: u8) -> u8

Source

impl Rem for u16

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

Source

type Output = u16

Source

fn rem(self, other: u16) -> u16

Source

impl Rem for u32

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

Source

type Output = u32

Source

fn rem(self, other: u32) -> u32

Source

impl Rem for u64

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

Source

type Output = u64

Source

fn rem(self, other: u64) -> u64

Source

impl Rem for u128

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

Source

type Output = u128

Source

fn rem(self, other: u128) -> u128

Source

impl Rem for usize

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

Source

type Output = usize

Source

fn rem(self, other: usize) -> usize

Implementors