pub trait Rem<Rhs = Self> {
type Output;
// Required method
fn rem(self, rhs: Rhs) -> Self::Output;
}Required Associated Types
Required Methods
Implementations on Foreign Types
Sourceimpl Rem for i8
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for i8
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0 or if self / other results in overflow.
Sourceimpl Rem for i16
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for i16
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0 or if self / other results in overflow.
Sourceimpl Rem for i32
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for i32
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0 or if self / other results in overflow.
Sourceimpl Rem for i64
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for i64
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0 or if self / other results in overflow.
Sourceimpl Rem for i128
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for i128
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0 or if self / other results in overflow.
Sourceimpl Rem for isize
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for isize
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0 or if self / other results in overflow.
Sourceimpl Rem for u8
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for u8
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0.
Sourceimpl Rem for u16
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for u16
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0.
Sourceimpl Rem for u32
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for u32
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0.
Sourceimpl Rem for u64
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for u64
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0.
Sourceimpl Rem for u128
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for u128
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0.
Sourceimpl Rem for usize
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
impl Rem for usize
This operation satisfies n % d == n - (n / d) * d. The
result has the same sign as the left operand.
Panics
This operation will panic if other == 0.